==> rest-hapi-2.1.0.tgz: package/CONTRIBUTING.md <==
# Contributing to rest-hapi

Hey there! We’re really excited that you are interested in contributing to
rest-hapi. Before submitting your contribution though, please make sure to take
a moment and read through the following guidelines.

## Code of Conduct

Please note that this project has a [Code of Conduct](CODE_OF_CONDUCT.md). It's
important that you review and enforce it.

## Code contributions

Here is a quick guide to doing code contributions to the library.

1.  Find some issue you're interested in, or a feature that you'd like to
    tackle. Also make sure that no one else is already working on it. If it's a
    feature you're requesting, make sure it's aligned with the direction of the
    project by creating an issue and discussing it with the core maintainers. We
    don't want you to be disappointed.
2. Fork the repo
3. Create a branch off of the *master* branch. Prefix your branch with either "feature/", "bugfix/", or something similar describing the type of update, and then add a descriptive name such as "bugfix/random\_files_erased".
4. Add your changes.
  * Please try to avoid monolithic commits. 
  * Code must follow the [Javascript Standard Style](https://standardjs.com/).
  * Your code must pass eslint filters to be able to commit.
5. Make sure your master branch is [in sync/up-to-date with the original](https://help.github.com/articles/syncing-a-fork/).
6. Before submitting a pull request, merge in your synced master branch with your current branch and resolve any conflicts.
7. Once all conflicts are resolved, submit a pull request to the origin master branch.
8. Your pull request will be reviewed along with change requests or comments.
9. After all requests are complete, your pull request will be merged in.
10. Celebrate! :tada:

**NOTE**: Don't forget to [update the docs](https://jkheadley.github.io/rest-hapi/docs/quick-start.html)! 😉

### This is my first Pull Request, where can I learn how to contribute?

You can take this free course:
[_How to Contribute to an Open Source Project on GitHub_](https://egghead.io/courses/how-to-contribute-to-an-open-source-project-on-github).

==> rest-hapi-3.1.0.tgz: package/CONTRIBUTING.md <==
# Contributing to rest-hapi

Hey there! We’re really excited that you are interested in contributing to
rest-hapi. Before submitting your contribution though, please make sure to take
a moment and read through the following guidelines.

## Code of Conduct

Please note that this project has a [Code of Conduct](CODE_OF_CONDUCT.md). It's
important that you review and enforce it.

## Code contributions

Here is a quick guide to doing code contributions to the library.

1.  Find some issue you're interested in, or a feature that you'd like to
    tackle. Also make sure that no one else is already working on it. If it's a
    feature you're requesting, make sure it's aligned with the direction of the
    project by creating an issue and discussing it with the core maintainers. We
    don't want you to be disappointed.
2. Fork the repo
3. Create a branch off of the *master* branch. Prefix your branch with either "feature/", "bugfix/", or something similar describing the type of update, and then add a descriptive name such as "bugfix/random\_files_erased".
4. Add your changes.
  * Please try to avoid monolithic commits. 
  * Code must follow the [Javascript Standard Style](https://standardjs.com/).
  * Your code must pass eslint filters to be able to commit.
5. Make sure your master branch is [in sync/up-to-date with the original](https://help.github.com/articles/syncing-a-fork/).
6. Before submitting a pull request, merge in your synced master branch with your current branch and resolve any conflicts.
7. Once all conflicts are resolved, submit a pull request to the origin master branch.
8. Your pull request will be reviewed along with change requests or comments.
9. After all requests are complete, your pull request will be merged in.
10. Celebrate! :tada:

**NOTE**: Don't forget to [update the docs](https://resthapi.com/docs/quick-start.html)! 😉

### This is my first Pull Request, where can I learn how to contribute?

You can take this free course:
[_How to Contribute to an Open Source Project on GitHub_](https://egghead.io/courses/how-to-contribute-to-an-open-source-project-on-github).
